==> dtk6declarative-debug-6.0.50-1-x86_64.pkg.tar.zst: usr/src/debug/dtk6declarative/dtk6declarative/qt6/src/.qt/rcc/qrc_qmake_org_deepin_dtk.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x3,0xd8,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xa1,0xc,0x75,0x1e,0x0,0x76,0x5f,0x57,0x1d,0x30,0x55,0x73,
  0xe7,0x93,0x44,0xc6,0xca,0x2d,0x9b,0xb2,0xc6,0x9,0x71,0x2c,0x37,0x9b,0xc9,0x76,
  0x66,0x77,0x99,0xa9,0x4b,0x86,0x86,0x54,0x95,0x1c,0x53,0x0,0x4f,0x0,0x4d,0x0,
  0x2e,0x2e,0x4f,0xa0,0x95,0x8a,0xb6,0xdc,0x6e,0x17,0x77,0x3a,0x1,0x4,0x8,0x82,
  0x42,0xa0,0x95,0x35,0xa8,0xc5,0xf9,0xc,0x60,0x30,0x18,0x4c,0xbc,0x3,0x44,0x80,
  0xff,0x39,0x3f,0x0,0x6c,0x55,0x48,0x70,0xd8,0x8f,0xd3,0xbf,0x52,0x5b,0x3a,0x9d,
  0x2a,0x1d,0x84,0x0,0xa7,0x53,0x6c,0xef,0x22,0xed,0xe4,0x6c,0xeb,0x2c,0xd0,0x9f,
  0x38,0x1b,0xe4,0xb4,0x1,0x40,0xcd,0x4,0x4e,0xdf,0xcf,0x4,0x13,0x6f,0xe0,0x2d,
  0xb2,0xad,0x2,0x93,0xcb,0x8e,0xee,0x94,0x57,0xa7,0x5a,0xe3,0x65,0x25,0x5e,0x3b,
  0xa4,0xe3,0x7a,0x12,0x2f,0x2e,0x3f,0x46,0xcb,0x9c,0x4e,0xdb,0x52,0x19,0xa9,0x78,
  0x6b,0xd5,0xce,0x4a,0x5d,0x82,0xe5,0xf9,0x65,0xde,0x96,0xf2,0x19,0xaf,0x82,0xb4,
  0xa,0x18,0xd7,0x3a,0x4e,0x4e,0xdb,0xd5,0x30,0x97,0x55,0xb5,0xeb,0x18,0xb7,0x2b,
  0x32,0x39,0xed,0xdc,0xe6,0x20,0xad,0xc2,0x6d,0x77,0x54,0x30,0xde,0x11,0x84,0x69,
  0x61,0x1,0x67,0xac,0xa7,0x7a,0x63,0x2e,0x21,0x7c,0xa6,0x8d,0x5a,0xad,0xa3,0xb7,
  0xb1,0x31,0xa7,0xd4,0x15,0xac,0xb5,0xe5,0x75,0xdd,0x34,0xd4,0xc9,0x68,0x99,0x1b,
  0x35,0x29,0xe7,0x7b,0xa6,0x7a,0x47,0x3e,0x25,0x84,0xa7,0x2c,0x6d,0xef,0xf1,0x76,
  0x2e,0x65,0x2e,0xc2,0xda,0xd5,0x91,0xe7,0x44,0x93,0x7e,0x97,0x16,0x7d,0x19,0x18,
  0x9d,0x52,0xe0,0x5b,0xa9,0x33,0x23,0xd5,0x34,0xbf,0x25,0x95,0xe1,0x6c,0x31,0x80,
  0x2a,0x2,0x27,0x3e,0x6b,0x4b,0x7d,0x25,0xbf,0xd9,0x19,0xbb,0xa7,0x5a,0xee,0x31,
  0xf4,0x4c,0xe9,0x12,0x8,0xcf,0xd3,0x72,0x9,0x82,0x56,0x7e,0x7a,0x95,0xbc,0xca,
  0x92,0xb9,0xb8,0xa5,0x6c,0xff,0x28,0xf9,0xcf,0x93,0xbd,0x92,0x1b,0xf2,0x9d,0x66,
  0xbb,0x27,0xff,0xd8,0x52,0xf8,0xdd,0xd4,0xd1,0xbc,0xee,0x4c,0x61,0xc7,0x8a,0x61,
  0xf3,0xfa,0x10,0x82,0xd6,0xa9,0xce,0xe9,0x2d,0x81,0x4b,0xa8,0xb1,0xce,0x8,0x8d,
  0x48,0x92,0xa4,0x90,0x36,0x3,0x41,0x8,0xc2,0x70,0x25,0x63,0x94,0x1d,0x31,0xc,
  0x89,0x32,0xc,0x22,0x69,0x8a,0x34,0x49,0x3a,0x1d,0x8,0x9b,0xf6,0x3c,0xe0,0xd4,
  0x70,0xdb,0x2d,0x82,0x31,0xc0,0xe,0x2e,0x7a,0x82,0x4e,0xd6,0x70,0x13,0x5,0x77,
  0x62,0xca,0x5,0x72,0xa8,0x76,0x35,0x1e,0xb8,0x49,0xc0,0x3a,0x1d,0xcc,0xe3,0x9e,
  0xe,0xa7,0xbc,0x51,0x50,0x4b,0xa0,0x4e,0x96,0xab,0xc7,0x69,0xbf,0x50,0x88,0xea,
  0xc,0xca,0xe4,0xa2,0xa2,0x51,0x20,0xbf,0x92,0x6e,0xe,0x75,0x4e,0x46,0xe7,0xca,
  0x53,0xaa,0x82,0x1b,0xce,0x85,0x40,0x42,0xd5,0x3e,0xed,0x2d,0xb6,0x96,0xd6,0xd1,
  0x58,0x92,0x9f,0xf2,0xe0,0xe,0x2b,0x62,0x9b,0x33,0xaa,0xb4,0x82,0xd2,0x8c,0xf6,
  0x9b,0x41,0x8b,0x54,0x91,0xf7,0x5c,0xe,0xdd,0xd4,0x6b,0x10,0x68,0x5a,0x57,0x84,
  0x43,0xb5,0x6c,0x3a,0xa3,0xd1,0xb1,0x69,0x1a,0x9f,0x34,0xfd,0xdc,0xf3,0x5e,0xaf,
  0xff,0xe2,0x23,0xb2,0xce,0xe0,0x31,0x86,0x62,0xa8,0x87,0x58,0x35,0xfb,0x2c,0x16,
  0x7b,0x86,0x45,0xc,0xdc,0x95,0x30,0xa6,0x63,0xf3,0x6c,0x28,0xd7,0x4b,0xbf,0x34,
  0x9c,0xea,0x22,0x2a,0xa7,0x3c,0x79,0xbc,0x3a,0x32,0x54,0x3c,0x5e,0x8e,0x2e,0xcb,
  0xcd,0x2c,0x59,0x37,0x9b,0x7c,0x82,0x1d,0x55,0xb1,0x8d,0x79,0xbe,0x88,0xd7,0x18,
  0xe7,0xec,0xaf,0xe5,0xe7,0x29,0xfe,0x1f,0x4f,0x31,0xc7,0x6d,0x75,0xa2,0x4,0x4a,
  0x7a,0xba,0x49,0x84,0x48,0x81,0x5b,0xdc,0x96,0x3f,0x44,0x84,0x55,0x9e,0x77,0xac,
  0xb9,0xca,0xa4,0x58,0x47,0xab,0xee,0xdd,0x39,0xe5,0x1f,0x60,0xe,0x60,0x1f,0xd0,
  0xb0,0x95,0x1c,0x83,0x63,0xfd,0xc8,0x5,0x37,0x62,0x45,0xef,0x3e,0x22,0x49,0x78,
  0xb7,0x9b,0x5d,0x70,0x48,0x3d,0x4,0x40,0xb2,0xdb,0x50,0x8e,0xaf,0x44,0xd1,0xd6,
  0xe8,0x9b,0x94,0x6d,0xa,0x2,0xb5,0x39,0x33,0xc4,0x6b,0x8b,0x10,0x7c,0x70,0x34,
  0xd,0x2c,0x43,0x4,0xc9,0xef,0x18,0x90,0xac,0xef,0xb7,0x8,0x44,0x20,0xa9,0x3c,
  0xd9,0xa9,0xed,0x33,0xa5,0x9d,0x8d,0x33,0x54,0xd,0xf3,0x3b,0x37,0x19,0x73,0x15,
  0xcb,0x96,0x67,0x31,0xff,0x49,0xab,0x7e,0xae,0xbc,0x69,0x95,0x6f,0x51,0x15,0xc9,
  0xca,0xa4,0x6,0x91,0x45,0x1,0x84,0xde,0x4c,0xd6,0x2,0xea,0xdb,0xd4,0x49,0xf7,
  0x10,0x2e,0x59,0x91,0x95,0xa,0x2,0xd9,0x32,0xf7,0x1a,0x29,0xff,0x10,0xd5,0x30,
  0xce,0xbd,0x6f,0x85,0x6a,0xdf,0x3a,0x60,0xf8,0x10,0xb2,0x8e,0x21,0x39,0xb1,0xc6,
  0x2d,0xf,0x46,0x64,0x64,0x5e,0x5a,0x7b,0xd3,0x5e,0xbe,0xa3,0x33,0xbb,0x7a,0x83,
  0x75,0x9d,0xb1,0xcf,0x1,0x73,0xc7,0x8,0xce,0x67,0x43,0xc0,0x4e,0x60,0x18,0xb0,
  0xf9,0x59,0xb1,0x98,0xd4,0x76,0x56,0xd4,0x1a,0xd7,0xca,0x90,0x62,0xf1,0xf9,0xa4,
  0x47,0x56,0x2,0x51,0xfd,0x7,0x2e,0x8f,0x37,0xe1,0x5a,0x21,0xd3,0xe0,0x11,0x96,
  0x6,0x74,0x5e,0x4a,0x31,0x94,0xa2,0x43,0x47,0x1c,0xa2,0xc1,0x41,0xca,0x75,0x9f,
  0x1b,0xc2,0x40,0xe4,0x88,0xa4,0x15,0x22,0xaf,0x5a,0xbe,0x71,0x8f,0x89,0x4,0xf5,
  0xbc,0xec,0x11,0x95,0x7d,0x99,0x1f,0x8f,0x59,0xb2,0x21,0xda,0x3,0x0,0x51,0x21,
  0x3a,0xc4,0xd8,0x9f,0x48,0x5d,0xd,0xc2,0x2d,0x86,0x40,0x63,0x45,0xe5,0x7e,0xc,
  0x2b,0x44,0x71,0x85,0xa3,0xcb,0x9e,0x3b,0x98,0xe0,0x80,0x48,0x49,0x45,0x9d,0x8e,
  0xf9,0x49,0x61,0xb2,0x3f,0xd,0x2e,0x13,0x7a,0x4,0x50,0x22,0xd1,0x54,0xef,0x30,
  0xed,0xac,0xc9,0xf7,0x84,0x46,0x9e,0xeb,0xb,0xbb,0xb8,0xf0,0xb1,0x7c,0x78,0xd3,
  0x63,0x76,0xd0,0x96,0x3,0x48,0xa,0xb,0x1d,0xcc,0xd9,0x1c,0x16,0xcf,0x80,0x47,
  0xcd,0x48,0x51,0x23,0x0,0x57,0x5,
  
};

static const unsigned char qt_resource_name[] = {
  // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // deepin
  0x0,0x6,
  0x6,0xab,0xc6,0xfe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,
    // dtk
  0x0,0x3,
  0x0,0x0,0x6b,0xab,
  0x0,0x64,
  0x0,0x74,0x0,0x6b,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9b,0xb2,0xcb,0xdf,0x0,
  // :/org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9b,0xb2,0xcb,0xdf,0x0,
  // :/org/deepin
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9b,0xb2,0xcb,0xdf,0x0,
  // :/org/deepin/dtk
  0x0,0x0,0x0,0x1e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9b,0xb2,0xcb,0xdf,0x0,
  // :/org/deepin/dtk/qmldir
  0x0,0x0,0x0,0x2a,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0xb2,0xcb,0xdf,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> dtk6declarative-debug-6.0.50-2-x86_64.pkg.tar.zst: usr/src/debug/dtk6declarative/dtk6declarative/qt6/src/.qt/rcc/qrc_qmake_org_deepin_dtk.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x3,0xd8,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xa1,0xc,0x75,0x1e,0x0,0x76,0x5f,0x57,0x1d,0x30,0x55,0x73,
  0xe7,0x93,0x44,0xc6,0xca,0x2d,0x9b,0xb2,0xc6,0x9,0x71,0x2c,0x37,0x9b,0xc9,0x76,
  0x66,0x77,0x99,0xa9,0x4b,0x86,0x86,0x54,0x95,0x1c,0x53,0x0,0x4f,0x0,0x4d,0x0,
  0x2e,0x2e,0x4f,0xa0,0x95,0x8a,0xb6,0xdc,0x6e,0x17,0x77,0x3a,0x1,0x4,0x8,0x82,
  0x42,0xa0,0x95,0x35,0xa8,0xc5,0xf9,0xc,0x60,0x30,0x18,0x4c,0xbc,0x3,0x44,0x80,
  0xff,0x39,0x3f,0x0,0x6c,0x55,0x48,0x70,0xd8,0x8f,0xd3,0xbf,0x52,0x5b,0x3a,0x9d,
  0x2a,0x1d,0x84,0x0,0xa7,0x53,0x6c,0xef,0x22,0xed,0xe4,0x6c,0xeb,0x2c,0xd0,0x9f,
  0x38,0x1b,0xe4,0xb4,0x1,0x40,0xcd,0x4,0x4e,0xdf,0xcf,0x4,0x13,0x6f,0xe0,0x2d,
  0xb2,0xad,0x2,0x93,0xcb,0x8e,0xee,0x94,0x57,0xa7,0x5a,0xe3,0x65,0x25,0x5e,0x3b,
  0xa4,0xe3,0x7a,0x12,0x2f,0x2e,0x3f,0x46,0xcb,0x9c,0x4e,0xdb,0x52,0x19,0xa9,0x78,
  0x6b,0xd5,0xce,0x4a,0x5d,0x82,0xe5,0xf9,0x65,0xde,0x96,0xf2,0x19,0xaf,0x82,0xb4,
  0xa,0x18,0xd7,0x3a,0x4e,0x4e,0xdb,0xd5,0x30,0x97,0x55,0xb5,0xeb,0x18,0xb7,0x2b,
  0x32,0x39,0xed,0xdc,0xe6,0x20,0xad,0xc2,0x6d,0x77,0x54,0x30,0xde,0x11,0x84,0x69,
  0x61,0x1,0x67,0xac,0xa7,0x7a,0x63,0x2e,0x21,0x7c,0xa6,0x8d,0x5a,0xad,0xa3,0xb7,
  0xb1,0x31,0xa7,0xd4,0x15,0xac,0xb5,0xe5,0x75,0xdd,0x34,0xd4,0xc9,0x68,0x99,0x1b,
  0x35,0x29,0xe7,0x7b,0xa6,0x7a,0x47,0x3e,0x25,0x84,0xa7,0x2c,0x6d,0xef,0xf1,0x76,
  0x2e,0x65,0x2e,0xc2,0xda,0xd5,0x91,0xe7,0x44,0x93,0x7e,0x97,0x16,0x7d,0x19,0x18,
  0x9d,0x52,0xe0,0x5b,0xa9,0x33,0x23,0xd5,0x34,0xbf,0x25,0x95,0xe1,0x6c,0x31,0x80,
  0x2a,0x2,0x27,0x3e,0x6b,0x4b,0x7d,0x25,0xbf,0xd9,0x19,0xbb,0xa7,0x5a,0xee,0x31,
  0xf4,0x4c,0xe9,0x12,0x8,0xcf,0xd3,0x72,0x9,0x82,0x56,0x7e,0x7a,0x95,0xbc,0xca,
  0x92,0xb9,0xb8,0xa5,0x6c,0xff,0x28,0xf9,0xcf,0x93,0xbd,0x92,0x1b,0xf2,0x9d,0x66,
  0xbb,0x27,0xff,0xd8,0x52,0xf8,0xdd,0xd4,0xd1,0xbc,0xee,0x4c,0x61,0xc7,0x8a,0x61,
  0xf3,0xfa,0x10,0x82,0xd6,0xa9,0xce,0xe9,0x2d,0x81,0x4b,0xa8,0xb1,0xce,0x8,0x8d,
  0x48,0x92,0xa4,0x90,0x36,0x3,0x41,0x8,0xc2,0x70,0x25,0x63,0x94,0x1d,0x31,0xc,
  0x89,0x32,0xc,0x22,0x69,0x8a,0x34,0x49,0x3a,0x1d,0x8,0x9b,0xf6,0x3c,0xe0,0xd4,
  0x70,0xdb,0x2d,0x82,0x31,0xc0,0xe,0x2e,0x7a,0x82,0x4e,0xd6,0x70,0x13,0x5,0x77,
  0x62,0xca,0x5,0x72,0xa8,0x76,0x35,0x1e,0xb8,0x49,0xc0,0x3a,0x1d,0xcc,0xe3,0x9e,
  0xe,0xa7,0xbc,0x51,0x50,0x4b,0xa0,0x4e,0x96,0xab,0xc7,0x69,0xbf,0x50,0x88,0xea,
  0xc,0xca,0xe4,0xa2,0xa2,0x51,0x20,0xbf,0x92,0x6e,0xe,0x75,0x4e,0x46,0xe7,0xca,
  0x53,0xaa,0x82,0x1b,0xce,0x85,0x40,0x42,0xd5,0x3e,0xed,0x2d,0xb6,0x96,0xd6,0xd1,
  0x58,0x92,0x9f,0xf2,0xe0,0xe,0x2b,0x62,0x9b,0x33,0xaa,0xb4,0x82,0xd2,0x8c,0xf6,
  0x9b,0x41,0x8b,0x54,0x91,0xf7,0x5c,0xe,0xdd,0xd4,0x6b,0x10,0x68,0x5a,0x57,0x84,
  0x43,0xb5,0x6c,0x3a,0xa3,0xd1,0xb1,0x69,0x1a,0x9f,0x34,0xfd,0xdc,0xf3,0x5e,0xaf,
  0xff,0xe2,0x23,0xb2,0xce,0xe0,0x31,0x86,0x62,0xa8,0x87,0x58,0x35,0xfb,0x2c,0x16,
  0x7b,0x86,0x45,0xc,0xdc,0x95,0x30,0xa6,0x63,0xf3,0x6c,0x28,0xd7,0x4b,0xbf,0x34,
  0x9c,0xea,0x22,0x2a,0xa7,0x3c,0x79,0xbc,0x3a,0x32,0x54,0x3c,0x5e,0x8e,0x2e,0xcb,
  0xcd,0x2c,0x59,0x37,0x9b,0x7c,0x82,0x1d,0x55,0xb1,0x8d,0x79,0xbe,0x88,0xd7,0x18,
  0xe7,0xec,0xaf,0xe5,0xe7,0x29,0xfe,0x1f,0x4f,0x31,0xc7,0x6d,0x75,0xa2,0x4,0x4a,
  0x7a,0xba,0x49,0x84,0x48,0x81,0x5b,0xdc,0x96,0x3f,0x44,0x84,0x55,0x9e,0x77,0xac,
  0xb9,0xca,0xa4,0x58,0x47,0xab,0xee,0xdd,0x39,0xe5,0x1f,0x60,0xe,0x60,0x1f,0xd0,
  0xb0,0x95,0x1c,0x83,0x63,0xfd,0xc8,0x5,0x37,0x62,0x45,0xef,0x3e,0x22,0x49,0x78,
  0xb7,0x9b,0x5d,0x70,0x48,0x3d,0x4,0x40,0xb2,0xdb,0x50,0x8e,0xaf,0x44,0xd1,0xd6,
  0xe8,0x9b,0x94,0x6d,0xa,0x2,0xb5,0x39,0x33,0xc4,0x6b,0x8b,0x10,0x7c,0x70,0x34,
  0xd,0x2c,0x43,0x4,0xc9,0xef,0x18,0x90,0xac,0xef,0xb7,0x8,0x44,0x20,0xa9,0x3c,
  0xd9,0xa9,0xed,0x33,0xa5,0x9d,0x8d,0x33,0x54,0xd,0xf3,0x3b,0x37,0x19,0x73,0x15,
  0xcb,0x96,0x67,0x31,0xff,0x49,0xab,0x7e,0xae,0xbc,0x69,0x95,0x6f,0x51,0x15,0xc9,
  0xca,0xa4,0x6,0x91,0x45,0x1,0x84,0xde,0x4c,0xd6,0x2,0xea,0xdb,0xd4,0x49,0xf7,
  0x10,0x2e,0x59,0x91,0x95,0xa,0x2,0xd9,0x32,0xf7,0x1a,0x29,0xff,0x10,0xd5,0x30,
  0xce,0xbd,0x6f,0x85,0x6a,0xdf,0x3a,0x60,0xf8,0x10,0xb2,0x8e,0x21,0x39,0xb1,0xc6,
  0x2d,0xf,0x46,0x64,0x64,0x5e,0x5a,0x7b,0xd3,0x5e,0xbe,0xa3,0x33,0xbb,0x7a,0x83,
  0x75,0x9d,0xb1,0xcf,0x1,0x73,0xc7,0x8,0xce,0x67,0x43,0xc0,0x4e,0x60,0x18,0xb0,
  0xf9,0x59,0xb1,0x98,0xd4,0x76,0x56,0xd4,0x1a,0xd7,0xca,0x90,0x62,0xf1,0xf9,0xa4,
  0x47,0x56,0x2,0x51,0xfd,0x7,0x2e,0x8f,0x37,0xe1,0x5a,0x21,0xd3,0xe0,0x11,0x96,
  0x6,0x74,0x5e,0x4a,0x31,0x94,0xa2,0x43,0x47,0x1c,0xa2,0xc1,0x41,0xca,0x75,0x9f,
  0x1b,0xc2,0x40,0xe4,0x88,0xa4,0x15,0x22,0xaf,0x5a,0xbe,0x71,0x8f,0x89,0x4,0xf5,
  0xbc,0xec,0x11,0x95,0x7d,0x99,0x1f,0x8f,0x59,0xb2,0x21,0xda,0x3,0x0,0x51,0x21,
  0x3a,0xc4,0xd8,0x9f,0x48,0x5d,0xd,0xc2,0x2d,0x86,0x40,0x63,0x45,0xe5,0x7e,0xc,
  0x2b,0x44,0x71,0x85,0xa3,0xcb,0x9e,0x3b,0x98,0xe0,0x80,0x48,0x49,0x45,0x9d,0x8e,
  0xf9,0x49,0x61,0xb2,0x3f,0xd,0x2e,0x13,0x7a,0x4,0x50,0x22,0xd1,0x54,0xef,0x30,
  0xed,0xac,0xc9,0xf7,0x84,0x46,0x9e,0xeb,0xb,0xbb,0xb8,0xf0,0xb1,0x7c,0x78,0xd3,
  0x63,0x76,0xd0,0x96,0x3,0x48,0xa,0xb,0x1d,0xcc,0xd9,0x1c,0x16,0xcf,0x80,0x47,
  0xcd,0x48,0x51,0x23,0x0,0x57,0x5,
  
};

static const unsigned char qt_resource_name[] = {
  // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // deepin
  0x0,0x6,
  0x6,0xab,0xc6,0xfe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,
    // dtk
  0x0,0x3,
  0x0,0x0,0x6b,0xab,
  0x0,0x64,
  0x0,0x74,0x0,0x6b,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9c,0x9,0x4c,0x8e,0x10,
  // :/org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9c,0x9,0x4c,0x8e,0x10,
  // :/org/deepin
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9c,0x9,0x4c,0x8e,0x10,
  // :/org/deepin/dtk
  0x0,0x0,0x0,0x1e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9c,0x9,0x4c,0x8e,0x10,
  // :/org/deepin/dtk/qmldir
  0x0,0x0,0x0,0x2a,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9c,0x9,0x4c,0x8e,0x10,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
